Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(30)

Unified Diff: chrome/browser/ui/cocoa/location_bar/location_bar_view_mac.h

Issue 2378623007: [Material] Update Material Security Verbose Decoration Flag (Closed)
Patch Set: Rebased again Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/about_flags.cc ('k') | chrome/browser/ui/cocoa/location_bar/location_bar_view_mac.mm » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/cocoa/location_bar/location_bar_view_mac.h
diff --git a/chrome/browser/ui/cocoa/location_bar/location_bar_view_mac.h b/chrome/browser/ui/cocoa/location_bar/location_bar_view_mac.h
index 1300cc9bd0fefa087e483c08fd2c6d95ccf418bc..de5c955e47e994fc9da4a40f5274865c7ee83f0e 100644
--- a/chrome/browser/ui/cocoa/location_bar/location_bar_view_mac.h
+++ b/chrome/browser/ui/cocoa/location_bar/location_bar_view_mac.h
@@ -315,13 +315,17 @@ class LocationBarViewMac : public LocationBar,
// Indicates whether or not the location bar is currently visible.
bool location_bar_visible_;
- // True if the HTTPS (non EV cert) state should be displayed on the security
- // state decoration.
+ // True if the HTTPS state should be displayed on the security state
+ // decoration.
bool should_show_secure_verbose_;
- // True if the security state decoration should be animated for changes in
- // the security level.
- bool should_animate_security_verbose_;
+ // True if the security state decoration should be animated for a secure
+ // security level.
+ bool should_animate_secure_verbose_;
+
+ // True if the security state decoration should be animated for a non-secure
+ // security level.
+ bool should_animate_nonsecure_verbose_;
// True if there's enough room for the omnibox to show the security verbose.
// If the verbose is displaying the EV cert, then this should always be true.
« no previous file with comments | « chrome/browser/about_flags.cc ('k') | chrome/browser/ui/cocoa/location_bar/location_bar_view_mac.mm » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698